Preguntas android: El androide libre.

Regalar apps: La opción que falta en Google Play
Heroes of Might and Magic III para tablets Android con gráficos HD en 2015
Rotation Orientation Manager, controla al detalle la orientación de pantalla de tu Android
Así se distribuyen los beneficios de Google Play
Tutorial: Desactiva la reproducción automática de vídeos en Facebook
Descarga las APKs de Google Play desde tu PC con Raccoon
UBER prohibido en España
HTC Desire 620
El alto precio de la innovación
El 40% de los móviles proceden de China
Login con Google+

## Crear cuenta

Nick Correo electrónico Contraseña Repetir contraseña Nombre Apellidos Web Descripción Avatar (máx. 500KB)
Buscar

## Categorías

Android general/Debate Aplicaciones/Busco una app Root y Roms Android básico Fallos y errores Recomendaciones ¿Qué compro? Smartphones Sugerencias e ideas Tablets Gustos androides Android Wear/Otros Android Trucos, noticias y novedades

## Preguntas más populares

### ¿Cuales han sido todos tus An

50

### ¿Cuándo se lanzó la promoci

40

### ¿Cuál fue el primer disposit

28

### ¿Qué es lo más divertido qu

24

### En EAL tenemos un OnePlus One,

22

## Usuarios más activos

### Gtrabal

141

### Enrique Pérez

124

### Manuel Block

67

### Paolo AC

47

### Fernando Benito

31

Las cookies son necesarias para el funcionamiento del sitio. Al acceder a Omicrono, acepta el uso de ellas. Aceptar Más información